import { defineStore } from 'pinia'

import { type Inventory } from 'src/types/data'

interface InventoryState {
  filePath: string,
  data: Inventory | null,
}

const fileTree = (state: InventoryState) => state.filePath.split(/(\\)|(\/)/gm)

export const useAppStore = defineStore('appStore', {
  state: () => ({
    currentInventory: {
      filePath: '',
      data: null as Inventory | null,
    } as InventoryState,
  }),
  getters: {
    fileTree(state) {
      return fileTree(state.currentInventory)
    },
    fileDirectory(state) {
      const split = fileTree(state.currentInventory)
      return state.currentInventory.filePath.replace(split[split.length - 1], '')
    },
    fileName(state) {
      const split = fileTree(state.currentInventory)
      return split[split.length - 1]
    },
  },
})

export type AppStoreDefinition = Omit<
  ReturnType<typeof useAppStore>,
  keyof ReturnType<typeof defineStore>
>
